# Examples: Tensor Network

```{toctree}
:numbered:
:maxdepth: 2

./examples/ex_tn_TRG
./examples/ex_tn_rand_uni_gate_graphs
./examples/ex_dmrg_periodic
./examples/ex_TEBD_evo
./examples/ex_MERA
./examples/ex_tensorflow_optimize_pbc_mps
./examples/ex_tn_circuit_sample_explore
./examples/ex_tn_train_circuit
./examples/ex_tn_qaoa_energy_bayesopt
./examples/ex_quimb_within_torch
./examples/ex_quimb_within_jax_flax_optax
./examples/ex_tn_tensor_fitting
./examples/ex_circuit_to_mpo
./examples/ex_htn_to_tn_2d
./examples/ex_tracing_tn_functions
./examples/ex_real_time_simple_update.ipynb
```


# Examples: Matrix

```{toctree}
:numbered:
:maxdepth: 2

./examples/ex_2d
./examples/ex_quench
./examples/ex_distributed_shift_invert
```


# Examples: Other

```{toctree}
:numbered:
:maxdepth: 2

./examples/schematic-demo
```